using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace RunningConfiguration
{
    public partial class RunningConfigurationForm : Form
    {
        public RunningConfigurationForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Click on the print configuration button
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void printButton_Click(object sender, EventArgs e)
        {
            MX301x.MSXE301x mx = new MX301x.MSXE301x();
            MX301x.Struct1 acquisition;
            MX301x.Struct2 autorefresh;
            MX301x.Struct3 sequence;
            MX301x.Struct7 trigger;
            ulong runningMode = 0;
            ulong dummy = 0;
            int returnValue = 0;

            // Reset text box
            configurationBox.Text = "";

            // Init the web reference
            try
            {
                mx.Url = "http://" + ipBox0.Text + "." + ipBox1.Text + "." + ipBox2.Text + "." + ipBox3.Text + ":5555";
            }
            catch (Exception ex)
            {
                configurationBox.Text = "Check the given IP address. Message : " + ex.Message;
                return;
            }
            mx.Timeout = 3000;

            // Call soap function
            try
            {
                if ((returnValue = mx.AnalogMeasureGetConfiguration(dummy, out runningMode, out acquisition, out autorefresh, out sequence, out trigger)) != 0)
                {
                    configurationBox.Text = "AnalogMeasureGetConfiguration return value is not 0 but : " + returnValue.ToString() ;
                    return;
                }
            }
            catch (Exception ex)
            {
                configurationBox.Text = "AnalogMeasureGetConfiguration exception. Check your firmware version. Message : " +  ex.Message;
                return;
            }

            // Print common
            this.AddText("Common part:");
            this.AddText("Running mode : \t\t" + runningMode.ToString() + "\t\t[ 0 : disabled | 1 : auto refresh | 2 : sequence ]");

            // Acquisition frequency
            if (runningMode != 0)
            {
                this.AddText("Convert time unit : \t\t" + acquisition.ulConvertTimeUnit.ToString() + "\t\t[ 0 : micro second | 1 : milli second | 2 : second ]");
                this.AddText("Convert time : \t\t" + acquisition.ulConvertTime.ToString() );
                this.AddText("Channel initialization : \t" + acquisition.ulChannelInitialization.ToString() );
            }

            // Auto refresh
            if (runningMode == 1)
            {
                this.AddText("--------------------------------------------------------------------------------------------------");
                this.AddText("Autorefresh part:");
                this.AddText("Channel mask : \t" + autorefresh.ulChannelMask.ToString() );
                this.AddText("Average mode : \t" + autorefresh.ulAverageMode.ToString() + "\t\t[ 0 : sequence | 1 : channel ]");
                this.AddText("Average value : \t" + autorefresh.ulAverageValue.ToString() );
                this.AddText("Data format : \t" + autorefresh.ulDataFormat.ToString() + "\t\t[ D0 timestamp 0 without, 1 with | D1 data format 0 digital 1 analog (in V) ]");
            }

            // Sequence
            if (runningMode == 2)
            {
                String sequenceArray = "Sequence array : \t\t[";

                this.AddText("--------------------------------------------------------------------------------------------------");
                this.AddText("Sequence part:");
                this.AddText("Sequence size : \t\t" + sequence.ulSequenceSize.ToString());

                for (int i = 0; i < (int)sequence.ulSequenceSize; i++)
                {
                    sequenceArray += sequence.ulSequence[i].ToString() + ", ";
                }
                sequenceArray += "]";
                this.AddText(sequenceArray);

                this.AddText("Sequence interrupt : \t" + sequence.ulSequenceInterrupt.ToString());
                this.AddText("Number of sequence : \t" + sequence.ulNbrOfSequence.ToString() + "\t\t[ 0 : continuous ]");
                this.AddText("Delay flag : \t\t" + sequence.ulDelayFlag.ToString() + "\t\t[ 0 : disabled | 1 : enabled ]");
                this.AddText("Delay mode : \t\t" + sequence.ulDelayMode.ToString() + "\t\t[ 0 : delay not used | 1 : mode 1 | 2 : mode 2 ]");
                this.AddText("Delay time unit : \t\t" + sequence.ulDelayTimeUnit.ToString() + "\t\t[ 1 : micro second | 2 : milli second | 3 : second ]");
                this.AddText("Delay time : \t\t" + sequence.ulDelayTime.ToString());
                this.AddText("Data format : \t\t" + sequence.ulDataFormat.ToString() + "\t\t[ D0 timestamp 0 without, 1 with | D1 counter 0 without, 1 with | D2 data format 0 digital 1 analog (in V) ]");
            }

        }

        /// <summary>
        /// Add a line of text in the text box
        /// </summary>
        /// <param name="text"></param>
        private void AddText(String text)
        {
            this.configurationBox.Text += text + "\r\n";
        }
    }
}